@@ -1,6 +1,9 @@
 #ifndef R_SANDBOX_H
 #define R_SANDBOX_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
 /**
  * This function verifies that the given path is allowed. Paths are allowed only if they don't
  * contain .. components (which would indicate directory traversal) and they are relative.
@@ -8,7 +11,7 @@
  * path are ok.
  */
 #if __WINDOWS__ && !defined(__CYGWIN__)
-R_API HANDLE r_sandbox_opendir(const char *path, WIN32_FIND_DATAW *entry, wchar_t *dir, wchar_t *wcpath);
+R_API HANDLE r_sandbox_opendir(const char *path, WIN32_FIND_DATAW *entry);
 #else
 R_API DIR* r_sandbox_opendir(const char *path);
 #endif
@@ -23,6 +26,11 @@ R_API bool r_sandbox_creat(const char *path, int mode);
 R_API int r_sandbox_open(const char *path, int mode, int perm);
 R_API FILE *r_sandbox_fopen(const char *path, const char *mode);
 R_API int r_sandbox_chdir(const char *path);
-R_API int r_sandbox_check_path(const char *path);
+R_API bool r_sandbox_check_path(const char *path);
 R_API int r_sandbox_kill(int pid, int sig);
+
+#ifdef __cplusplus
+}
+#endif
+
 #endif //  R_SANDBOX_H
